@@ -272,7 +272,8 @@ class UpdateConditions():
             task = EmergeLog(EmergeLogNamedTask(task_name))
             return (bool(PackageList(task.list)[pkg])
                     or Get('cl_update_force_depclean_set') == 'on'
-                    or Get('cl_update_outdated_kernel_set') == 'on')
+                    or Get('cl_update_outdated_kernel_set') == 'on'
+                    or Get('cl_update_world_hash_set') == 'on')
         return func
 
     @staticmethod
@@ -501,6 +502,9 @@ class ClUpdateAction(Action):
          'method': 'Update.drop_portage_state_hash()',
          'depend': Tasks.failed()
          },
+        {'name': 'drop_world_hash',
+         'method': 'Update.drop_world_state_hash()',
+         'depend': Tasks.failed()},
          {'name': 'update:set_current_level',
          'method': 'Update.update_increment_current_level()',
          'depend': (Tasks.success() & Tasks.hasnot("interrupt") &
@@ -521,6 +525,10 @@ class ClUpdateAction(Action):
          'method': 'Update.save_portage_state_hash()',
          'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
          },
+        {'name': 'update:save_world_hash',
+         'method': 'Update.save_world_state_hash()',
+         'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
+         },
         {'name': 'clear_migration_host',
          'method': 'Update.delete_binhost()',
          'depend': (Tasks.hasnot("check_schedule")), 
