@@ -961,11 +961,11 @@ class VariableClUpdateProfileCheckSyncAllowed(Variable):
             for rep in repos:
                 with open(f'{rep}/test', 'w') as inf:
                     inf.write("test")
-                quite_unlink(f"{rep}/test")
+                os.unlink(f"{rep}/test")
             path = self.Get(self.cache_path)
-            with open(f'{rep}/test', 'w') as inf:
+            with open(f'{path}/test', 'w') as inf:
                 inf.write("test")
-            quite_unlink(f"{rep}/test")
+            os.unlink(f"{path}/test")
         except OSError:
             return False
         return True
@@ -1573,9 +1573,7 @@ class VariableClUpdateKernelPkg(ReadonlyVariable):
     def get(self):
         src_path = self.Get('cl_update_kernel_src_path')
         if src_path:
-            qfile = process('/usr/bin/qfile', '-vqC', src_path)
-            if qfile.success():
-                return qfile.read().strip()
+            return
         return ""
 
 
